@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2003-2004 Imendio HB
+ * Copyright (C) 2003-2004 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License as
@@ -25,6 +25,8 @@
 #error "Only <loudmouth/loudmouth.h> can be included directly, this file may disappear or change contents."
 #endif
 
+G_BEGIN_DECLS
+
 typedef struct _LmSSL LmSSL;
 typedef enum {
 	LM_CERT_INVALID,
@@ -64,4 +66,6 @@ const unsigned char * lm_ssl_get_fingerprint (LmSSL          *ssl);
 LmSSL *               lm_ssl_ref             (LmSSL          *ssl);
 void                  lm_ssl_unref           (LmSSL          *ssl);
 
+G_END_DECLS
+
 #endif /* __LM_SSL_H__ */
